@@ -1,5 +1,5 @@
 package Time::Progress::Stored::Storage::Redis;
-$Time::Progress::Stored::Storage::Redis::VERSION = '1.001';
+$Time::Progress::Stored::Storage::Redis::VERSION = '1.002';
 use Moo;
 use true;
 extends "Time::Progress::Stored::Storage";
@@ -20,7 +20,7 @@ use JSON::Tiny qw/ encode_json decode_json /;
 
 has redis => (
     is       => "ro",
-    isa      => "Redis",
+    isa      => sub { shift->isa("Redis") },
     required => 1,
 );
 
